.. _robust_publisher:

hop.robust_publisher
####################

.. module:: hop.robust_publisher

.. autoclass:: PublicationJournal     
   :members: 

   .. automethod:: __init__

.. autoclass:: RobustProducer     
   :members: 

   .. automethod:: __init__
